==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebActiveStepChangedArgsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangedArgsDetailDescriptionMetadata } from "./WebActiveStepChangedArgsDetailDescriptionMetadata";
import { WebActiveStepChangedArgsEventArgsDescription } from "./WebActiveStepChangedArgsEventArgsDescription";
/**
 * @hidden
 */
var WebActiveStepChangedArgsEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangedArgsEventArgsDescriptionMetadata, _super);
    function WebActiveStepChangedArgsEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.b = function (a) {
        if (WebActiveStepChangedArgsEventArgsDescriptionMetadata.a == null) {
            WebActiveStepChangedArgsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveStepChangedArgsEventArgsDescriptionMetadata.c(WebActiveStepChangedArgsEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebActiveStepChangedArgsEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebActiveStepChangedArgsEventArgsDescriptionMetadata.a);
        WebActiveStepChangedArgsDetailDescriptionMetadata.d(a);
    };
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveStepChangedArgsEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebActiveStepChangedArgsDetail");
    };
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.d = function (a) {
        WebActiveStepChangedArgsEventArgsDescriptionMetadata.b(a);
        a.ad("WebActiveStepChangedArgsEventArgs", function () { return new WebActiveStepChangedArgsEventArgsDescription(); });
        a.ac("WebActiveStepChangedArgsEventArgs", WebActiveStepChangedArgsEventArgsDescriptionMetadata.a);
    };
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.$t = markType(WebActiveStepChangedArgsEventArgsDescriptionMetadata, 'WebActiveStepChangedArgsEventArgsDescriptionMetadata');
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.a = null;
    return WebActiveStepChangedArgsEventArgsDescriptionMetadata;
}(Base));
export { WebActiveStepChangedArgsEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebActiveStepChangedArgsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangedArgsDetailDescriptionMetadata } from "./WebActiveStepChangedArgsDetailDescriptionMetadata";
import { WebActiveStepChangedArgsEventArgsDescription } from "./WebActiveStepChangedArgsEventArgsDescription";
/**
 * @hidden
 */
var WebActiveStepChangedArgsEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangedArgsEventArgsDescriptionMetadata, _super);
    function WebActiveStepChangedArgsEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.b = function (a) {
        if (WebActiveStepChangedArgsEventArgsDescriptionMetadata.a == null) {
            WebActiveStepChangedArgsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveStepChangedArgsEventArgsDescriptionMetadata.c(WebActiveStepChangedArgsEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebActiveStepChangedArgsEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebActiveStepChangedArgsEventArgsDescriptionMetadata.a);
        WebActiveStepChangedArgsDetailDescriptionMetadata.d(a);
    };
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveStepChangedArgsEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebActiveStepChangedArgsDetail");
    };
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.d = function (a) {
        WebActiveStepChangedArgsEventArgsDescriptionMetadata.b(a);
        a.ae("WebActiveStepChangedArgsEventArgs", function () { return new WebActiveStepChangedArgsEventArgsDescription(); });
        a.ad("WebActiveStepChangedArgsEventArgs", WebActiveStepChangedArgsEventArgsDescriptionMetadata.a);
    };
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.$t = markType(WebActiveStepChangedArgsEventArgsDescriptionMetadata, 'WebActiveStepChangedArgsEventArgsDescriptionMetadata');
    WebActiveStepChangedArgsEventArgsDescriptionMetadata.a = null;
    return WebActiveStepChangedArgsEventArgsDescriptionMetadata;
}(Base));
export { WebActiveStepChangedArgsEventArgsDescriptionMetadata };
